@@ -9,15 +9,15 @@ Ms::Latn - Package for language Ms
 package Locale::CLDR::Locales::Ms::Latn;
 
 # This file auto generated
-#	on Fri 28 Jun  7:37:13 am GMT
+#	on Wed 15 Jan 11:22:39 am GMT
 
 use version;
 
-our $VERSION = version->declare('v0.45.0');
+our $VERSION = version->declare('v0.46.0');
 
-use v5.10.1;
+use v5.12.0;
 use mro 'c3';
-use if $^V ge v5.12.0, feature => 'unicode_strings';
+use feature 'unicode_strings';
 
 use Moo;
 
